==> kjy-center-api-0.7.0-ctc4-20191227.101136-1-sources.jar: cn/com/duiba/kjy/api/remoteservice/sellercard/RemoteSellerCardService.java <==
package cn.com.duiba.kjy.api.remoteservice.sellercard;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.kjy.api.dto.sellercard.CaseDto;
import cn.com.duiba.kjy.api.dto.sellercard.HonorDto;
import cn.com.duiba.kjy.api.dto.sellercard.SellerAuthRecordDto;
import cn.com.duiba.kjy.api.dto.sellercard.SellerCardDto;
import cn.com.duiba.kjy.api.dto.sellercard.SellerSplendidImageBean;
import cn.com.duiba.kjy.api.enums.sellercard.AuthStatusEnum;
import cn.com.duiba.kjy.api.params.sellercard.DoAuth4AdminParam;
import cn.com.duiba.kjy.api.params.sellercard.SellerAuthRecordParam;
import cn.com.duiba.kjy.api.params.sellercard.SellerCardParam;

import java.util.List;

/**
 * Created by dugq on 2019-08-01.
 */
@AdvancedFeignClient
public interface RemoteSellerCardService {


    /**
     * 跟新名片
     * card更像是seller表的扩展表。
     * 广义上不存在插入。只有销售有没有编辑过扩展信息而已。
     * @param param
     * @return
     */
    int update(SellerCardParam param);

    /**
     * 仅允许未提交过审核，或者审核失败的情况下提交审核
     * 分布式锁，避免同一类型重复提交而导致一些诡异的问题
     * @param param
     * @return  -1 ：已经有提交记录了，不可再提交  -2 已经通过了，不可再次提交
     */
    @Deprecated
    int addAuth(SellerAuthRecordDto param);

    /**
     * 数据序列化到hbase中。
     * 查询的时候会反序列化回来
     * id： 是按规则生成的唯一hbase key。存入到card表的honor字段中。多条记录，逗号隔开
     * @param honorDto
     * @return  -1 hbase操作失败  -2 sellerId未指定 0 修改数据库失败
     */
    int addHonor(HonorDto honorDto);

    /**
     * 根据key(id) 直接修改hbase中的数据。
     * @param honorDto
     * @return  -1 hbase操作失败  -2 sellerId未指定
     */
    int updateHonor(HonorDto honorDto);

    /**
     * 先删除hbase中的数据。再截取掉card表的honor字段对应的key
     * @param id
     * @return  -1 hbase中不存的记录 -2 用户card不存在
     */
    int deleteHonor(String id);

    /**
     * 数据序列化到hbase中。
     * 查询的时候会反序列化回来
     * id： 是按规则生成的唯一hbase key。存入到card表的case字段中。多条记录，逗号隔开
     * @param caseDto
     * @return  -1 hbase操作失败  -2 sellerId未指定 0 修改数据库失败
     */
    int addCase(CaseDto caseDto);

    /**
     * 根据key(id) 直接修改hbase中的数据。
     * @param caseDto
     * @return  -1 hbase操作失败  -2 sellerId未指定 0 数据库操作失败
     */
    int updateCase(CaseDto caseDto);

    /**
     * 先删除hbase中的数据。再截取掉card表的case字段对应的key
     * @param id
     * @return  -1 hbase中不存的记录 -2 用户card不存在
     */
    int deleteCase(String id);

    /**
     * 字符串会反序列化为对象
     * 缓存1分钟。
     * 跟新操作会清理缓存
     * @param sellerId
     * @return
     */
    SellerCardDto selectBySellerId(Long sellerId);

    /**
     * 转发前使用。
     * @param sellerId
     * @return
     */
    Long getScId(Long sellerId);

    /**
     * 管理端查询记录
     * @param param
     * @return
     */
    List<SellerAuthRecordDto> selectAuthRecordList4Admin(SellerAuthRecordParam param);

    Long selectAuthRecordCount4Admin(SellerAuthRecordParam param);

    /**
     * 获取销售提交的申请记录。每个类型取最近一次的提交记录
     * @param sellerId
     * @return
     */
    List<SellerAuthRecordDto> selectAuthRecordBySellerGroupByType(Long sellerId);

    /**
     * 根据代理人获取认证信息
     * @param sellerId
     * @return
     */
    List<SellerAuthRecordDto> selectAuthRecordBySeller(Long sellerId);

    /**
     * 管理员审核。为方便查询，审核通过的数据会根据需要序列化到card表authentication字段中存储。
     * @param param
     * @return -1: 记录不存在 -2 已经审核过了
     *
     */
    int doAuth4Admin(DoAuth4AdminParam param);

    /**
     * 数据存与hbase中，key存在card表的splendidImage
     * 每个card会有一个key。key是根据规则生成的
     * @param sid
     * @param url
     * @return
     */
    int updateSplendidImage(Long sid, String url);


    /**
     * 更新审核状态
     * @param id
     * @param authStatusEnum
     * @return
     */
    int updateSellerAuthRecordStatus(Long id, AuthStatusEnum authStatusEnum);

    /**
     * 根据主键Id获取名片详情 并补充代理人个人形象,公司名,中文名信息
     * @param id
     * @return
     */
    SellerCardDto selectSimpleDtoById(Long id);

    /**
     * 审核失败结果 标记为已读
     * @param id
     * @return
     */
    @Deprecated
    int readAuthResult(Long id,AuthStatusEnum authStatusEnum);

    /**
     * 是否为完善的代理人名片
     * @param sellerId
     * @return
     */
    Boolean isPerfect(Long sellerId);

    /**
     * 获取代理人名片完善度百分比  全部完成返回 100
     * @param sellerId
     * @return
     */
    Integer getCompeletePercent(Long sellerId);

    /**
     * 根据id查询审核记录
     * @param ids
     * @return
     */
    List<SellerAuthRecordDto> selectAuthRecordByIds(List<Long> ids);


    /**
     * 获取代理人名片 点滴精彩分页查询
     * @param sellerId
     * @param pageIndex
     * @param pageSize
     * @return
     */
    SellerSplendidImageBean getSellerSplendidImage(Long sellerId, Integer pageIndex, Integer pageSize);


}

==> kjy-center-api-0.8.48-ctc31-20200514.021707-1-sources.jar: cn/com/duiba/kjy/api/remoteservice/sellercard/RemoteSellerCardService.java <==
package cn.com.duiba.kjy.api.remoteservice.sellercard;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.kjy.api.dto.sellercard.AuthenticationDto;
import cn.com.duiba.kjy.api.dto.sellercard.CaseDto;
import cn.com.duiba.kjy.api.dto.sellercard.HonorDto;
import cn.com.duiba.kjy.api.dto.sellercard.SellerAuthRecordDto;
import cn.com.duiba.kjy.api.dto.sellercard.SellerCardDto;
import cn.com.duiba.kjy.api.dto.sellercard.SellerSplendidImageBean;
import cn.com.duiba.kjy.api.dto.sellercardv5.SellerCardBottomOfArticleDto;
import cn.com.duiba.kjy.api.dto.sellercardv5.SellerCardDtoV5;
import cn.com.duiba.kjy.api.dto.sellercardv5.SellerCardHonorDto;
import cn.com.duiba.kjy.api.dto.sellercardv5.SellerCardPersonalProfileDto;
import cn.com.duiba.kjy.api.dto.sellercardv5.SellerCardTopOfArticleDto;
import cn.com.duiba.kjy.api.dto.sellercardv5.SellerCardTopOfDetailDto;
import cn.com.duiba.kjy.api.enums.sellercard.AuthStatusEnum;
import cn.com.duiba.kjy.api.params.sellercard.SellerAuthRecordParam;
import cn.com.duiba.kjy.api.params.sellercard.SellerCardParam;

import java.util.List;

/**
 * Created by dugq on 2019-08-01.
 */
@AdvancedFeignClient
public interface RemoteSellerCardService {


    /**
     * 跟新名片
     * card更像是seller表的扩展表。
     * 广义上不存在插入。只有销售有没有编辑过扩展信息而已。
     * @param param
     * @return
     */
    int update(SellerCardParam param);

    /**
     * 仅允许未提交过审核，或者审核失败的情况下提交审核
     * 分布式锁，避免同一类型重复提交而导致一些诡异的问题
     * @param param
     * @return  -1 ：已经有提交记录了，不可再提交  -2 已经通过了，不可再次提交
     */
    @Deprecated
    int addAuth(SellerAuthRecordDto param);

    /**
     * 数据序列化到hbase中。
     * 查询的时候会反序列化回来
     * id： 是按规则生成的唯一hbase key。存入到card表的honor字段中。多条记录，逗号隔开
     * @param honorDto
     * @return  -1 hbase操作失败  -2 sellerId未指定 0 修改数据库失败
     */
    int addHonor(HonorDto honorDto);

    /**
     * 根据key(id) 直接修改hbase中的数据。
     * @param honorDto
     * @return  -1 hbase操作失败  -2 sellerId未指定
     */
    int updateHonor(HonorDto honorDto);

    /**
     * 先删除hbase中的数据。再截取掉card表的honor字段对应的key
     * @param id
     * @return  -1 hbase中不存的记录 -2 用户card不存在
     */
    int deleteHonor(String id);

    /**
     * 数据序列化到hbase中。
     * 查询的时候会反序列化回来
     * id： 是按规则生成的唯一hbase key。
     * tb_seller_card.cases字段中存储的是  以版本划分的成功案例的hbasekey, 例如:KjyCenter_K023_#{sellerId}_#{version}
     * 根据这个key 解析出 hbaseKey 的字符串  这些key对应真正的hbase的json值.
     * @param caseDto
     * @return  -1 hbase操作失败  -2 sellerId未指定 0 修改数据库失败
     */
    int addCase(CaseDto caseDto);

    /**
     * 根据key(id) 直接修改hbase中的数据。
     * @param caseDto
     * @return  -1 hbase操作失败  -2 sellerId未指定 0 数据库操作失败
     */
    int updateCase(CaseDto caseDto);

    /**
     * 更新个人案例的展示状态
     * @param sellerId 销售id
     * @param id
     * @param isShow
     * @return
     */
    Boolean updateCaseShowStatus(Long sellerId,String id,Boolean isShow);

    /**
     * 先删除hbase中的数据。再截取掉card表的case字段对应的key
     * @param id
     * @return  -1 hbase中不存的记录 -2 用户card不存在
     */
    int deleteCase(String id);

    /**
     * 字符串会反序列化为对象
     * 缓存1分钟。
     * 跟新操作会清理缓存
     * @param sellerId
     * @return
     */
    SellerCardDto selectBySellerId(Long sellerId);

    /**
     * 转发前使用。
     * @param sellerId
     * @return
     */
    Long getScId(Long sellerId);

    /**
     * 管理端查询记录
     * @param param
     * @return
     */
    List<SellerAuthRecordDto> selectAuthRecordList4Admin(SellerAuthRecordParam param);

    Long selectAuthRecordCount4Admin(SellerAuthRecordParam param);

    /**
     * 获取销售提交的申请记录。每个类型取最近一次的提交记录
     * @param sellerId
     * @return
     */
    List<SellerAuthRecordDto> selectAuthRecordBySellerGroupByType(Long sellerId);

    /**
     * 根据代理人获取认证信息
     * @param sellerId
     * @return
     */
    List<SellerAuthRecordDto> selectAuthRecordBySeller(Long sellerId);


    /**
     * 数据存与hbase中，key存在card表的splendidImage
     * 每个card会有一个key。key是根据规则生成的
     * @param sid
     * @param url
     * @return
     */
    int updateSplendidImage(Long sid, String url);


    /**
     * 更新审核状态
     * @param id
     * @param authStatusEnum
     * @return
     */
    int updateSellerAuthRecordStatus(Long id, AuthStatusEnum authStatusEnum);

    /**
     * 根据主键Id获取名片详情 并补充代理人个人形象,公司名,中文名信息
     * @param id
     * @return
     */
    SellerCardDto selectSimpleDtoById(Long id);

    /**
     * 审核失败结果 标记为已读
     * @param id
     * @return
     */
    @Deprecated
    int readAuthResult(Long id,AuthStatusEnum authStatusEnum);

    /**
     * 是否为完善的代理人名片
     * @param sellerId
     * @return
     */
    Boolean isPerfect(Long sellerId);

    /**
     * 获取代理人名片完善度百分比  全部完成返回 100
     * @param sellerId
     * @return
     */
    Integer getCompeletePercent(Long sellerId);

    /**
     * 根据id查询审核记录
     * @param ids
     * @return
     */
    List<SellerAuthRecordDto> selectAuthRecordByIds(List<Long> ids);


    /**
     * 获取代理人名片 点滴精彩分页查询
     * @param sellerId
     * @param pageIndex
     * @param pageSize
     * @return
     */
    SellerSplendidImageBean getSellerSplendidImage(Long sellerId, Integer pageIndex, Integer pageSize);

    /**------名片5.2.0后 接口模块化-------**/

    /**
     * 获取tb_seller_card dto对象
     * @param sellerId
     * @return
     */
    SellerCardDtoV5 getSimpleDtoBySellerId(Long sellerId);

    /**
     * 获取名片顶部详情页信息
     * @param sellerId
     * @return
     */
    SellerCardTopOfDetailDto getTopOfDetail(Long sellerId);

    /**
     * 个人介绍模块
     * @param sellerId
     * @return
     */
    SellerCardPersonalProfileDto getPersonalProfile(Long sellerId);

    /**
     * 客户投保实录列表
     * @param sellerId
     * @return
     */
    List<CaseDto> getSellerCardCaseList(Long sellerId);

    /**
     * 名片获奖记录模块
     * @param sellerId
     * @return
     */
    SellerCardHonorDto getSellerCardHonorDto(Long sellerId);

    /**
     * 素材顶部名片
     * @param sellerId
     * @return
     */
    SellerCardTopOfArticleDto getSellerCardTopOfContent(Long sellerId);

    /**
     * 素材底部名片
     * @param sellerId
     * @return
     */
    SellerCardBottomOfArticleDto getSellerCardBottomOfContent(Long sellerId);

    /**
     * 获取证书荣誉
     * @param sellerId
     * @return
     */
    List<AuthenticationDto> getAuthenticationDto(Long sellerId);

}
